@@ -2,6 +2,7 @@ import logging
 from abc import abstractmethod
 from dataclasses import dataclass
 from json.decoder import JSONDecodeError
+
 from pydispix.errors import RateLimitBreached
 from typing import Union
 
@@ -41,10 +42,13 @@ class ChurchClient(Client):
         return resolve_url_endpoint(self.base_church_url, endpoint)
 
     @abstractmethod
-    def get_task(self, endpoint: str = "get_task") -> ChurchTask:
+    def get_task(self, endpoint: str = "get_task", repeat_delay: int = 5) -> ChurchTask:
         """
         Get task from the church, this is an abstract method, you'll need
         to override this to get it to work with your church's specific API.
+
+        `repeat_delay` is the time we will wait for, if the church currently
+        doesn't have any aviable tasks for us.
         """
 
     @abstractmethod
@@ -58,6 +62,7 @@ class ChurchClient(Client):
         self,
         submit_endpoint: str = "submit_task",
         show_progress: bool = False,
+        repeat_delay: int = 5,
         repeat_on_ratelimit: bool = True,
     ):
         """
@@ -66,11 +71,13 @@ class ChurchClient(Client):
         In case we hit initial rate limit from `set_pixel`, the rate limit is waited out,
         and we proceed with a new task, since the church's API time limit for that task
         has already likely expired.
+
+        `repeat_delay` is the delay to wait, if the church doesn't have any more aviable tasks.
         """
         # This can't just use the `set_pixel`, because we need to send submit message to the church
         # before we wait for the rate limits, this is also why we use `make_raw_request` instead
         # of just using `make_requests` that handles the rate limits for us
-        task = self.get_task()
+        task = self.get_task(repeat_delay=repeat_delay)
         logger.info(f"Running church task: {task}")
         url = self.resolve_endpoint("set_pixel")
         try:
@@ -95,7 +102,7 @@ class ChurchClient(Client):
                 # If we can't get `data` key from obtained JSON,
                 # just use the pure JSON that's already set.
                 pass
-            logger.warning(f"Hit rate limit, request failed ({response_text})")
+            logger.warning(f"Hit pixels api rate limit, request failed ({response_text})")
             self.rate_limiter.wait(url, show_progress=show_progress)
             # There is no point in trying to fullfil this request now, just
             # rerunning and obtain a new request, the rate limit for set_pixel
@@ -115,7 +122,19 @@ class ChurchClient(Client):
         self.rate_limiter.wait(url, show_progress=show_progress)
         return status
 
-    def run_tasks(self, show_progress: bool = False):
+    def run_tasks(
+        self,
+        submit_endpoint: str = "submit_task",
+        show_progress: bool = False,
+        repeat_delay: int = 5
+    ):
         """Keep running church tasks forever."""
         while True:
-            self.run_task(show_progress=show_progress)
+            try:
+                self.run_task(
+                    submit_endpoint=submit_endpoint,
+                    show_progress=show_progress,
+                    repeat_delay=repeat_delay
+                )
+            except RateLimitBreached as exc:
+                logger.exception("Got rate limited, ignoring exception and moving to the next task", exc_info=exc)
